<?php
/**
 * Theme Ostrich Customizer
 *
 * @package Music Center
 *
 * latest_albums section
 */

$wp_customize->add_section(
	'music_center_latest_albums',
	array(
		'title' => esc_html__( 'Latest Albums Section', 'music-center' ),
		'panel' => 'music_center_home_panel',
	)
);

// latest_albums enable settings
$wp_customize->add_setting(
	'music_center_latest_albums',
	array(
		'sanitize_callback' => 'music_center_sanitize_select',
		'default' => 'disable'
	)
);

$wp_customize->add_control(
	'music_center_latest_albums',
	array(
		'section'		=> 'music_center_latest_albums',
		'label'			=> esc_html__( 'Content type:', 'music-center' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'music-center' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'music-center' ),
				'post' => esc_html__( 'Post', 'music-center' ),
		 	)
	)
);

$wp_customize->add_setting(
	'music_center_latest_albums_sub_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'	=> 'postMessage',
		'default'	=>  __('NEWEST ALBUMS & SINGLES.', 'music-center'),
	)
);

$wp_customize->add_control(
	'music_center_latest_albums_sub_title',
	array(
		'section'		=> 'music_center_latest_albums',
		'label'			=> esc_html__( 'Sub Title:', 'music-center' ),
		'active_callback' => 'music_center_if_latest_albums_enabled',
		
	)
);

$wp_customize->selective_refresh->add_partial( 
	'music_center_latest_albums_sub_title', 
	array(
        'selector'            => '#latest-albums p.section-subtitle',
		'render_callback'     => 'music_center_latest_albums_partial_sub_title',
	) 
);

$wp_customize->add_setting(
	'music_center_latest_albums_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'	=> 'postMessage',
		'default'	=>  __('Latest Release!!', 'music-center'),
	)
);

$wp_customize->add_control(
	'music_center_latest_albums_title',
	array(
		'section'		=> 'music_center_latest_albums',
		'label'			=> esc_html__( 'Title:', 'music-center' ),		
		'active_callback' => 'music_center_if_latest_albums_enabled',
		
	)
);

$wp_customize->selective_refresh->add_partial( 
	'music_center_latest_albums_title', 
	array(
        'selector'            => '#latest-albums h2.section-title',
		'render_callback'     => 'music_center_latest_albums_partial_title',
	) 
);

$wp_customize->add_setting(
	'music_center_latest_albums_description',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'	=> 'postMessage',
		'default'	=>  __('Proving that they are not your average country band, M-Slide blends old-fashioned country charm, lyrical wit and rock n’ roll grit into radio-friendly, hook-heavy pop nuggets.', 'music-center'),
	)
);

$wp_customize->add_control(
	'music_center_latest_albums_description',
	array(
		'section'		=> 'music_center_latest_albums',
		'label'			=> esc_html__( 'Description:', 'music-center' ),		
		'active_callback' => 'music_center_if_latest_albums_enabled',
		'type'			=> 'textarea'
		
	)
);

$wp_customize->selective_refresh->add_partial( 
	'music_center_latest_albums_description', 
	array(
        'selector'            => '#latest-albums .section-content p',
		'render_callback'     => 'music_center_latest_albums_partial_description',
	) 
);

$wp_customize->add_setting(
	'music_center_latest_albums_button_label',
	array(	
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> esc_html__( 'VIEW ALL RELEASE', 'music-center' ),
	'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'music_center_latest_albums_button_label',
	array(
	'label'       => __('Button Label', 'music-center'),  
	'section'     => 'music_center_latest_albums',   		
	'type'        => 'text',
	'active_callback'	=> 'music_center_if_latest_albums_enabled',
	)
);

$wp_customize->selective_refresh->add_partial( 
	'music_center_latest_albums_button_label', 
	array(
        'selector'            => '#latest-albums div.read-more a',
		'render_callback'     => 'music_center_latest_albums_partial_button',
	) 
);

$wp_customize->add_setting(
		'music_center_latest_albums_button_url',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	
	$wp_customize->add_control(
		'music_center_latest_albums_button_url',
		array(
			'section'		=> 'music_center_latest_albums',
			'label'			=> esc_html__( 'Button Url:', 'music-center' ),
			'type'			=> 'url',
			'active_callback'	=> 'music_center_if_latest_albums_enabled',
		)
	);

for ($i=1; $i <= 3; $i++) { 
	// latest_albums post setting
	$wp_customize->add_setting(
		'music_center_latest_albums_post_'.$i,
		array(
			'sanitize_callback' => 'music_center_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'music_center_latest_albums_post_'.$i,
		array(
			'section'		=> 'music_center_latest_albums',
			'label'			=> esc_html__( 'Post ', 'music-center' ).$i,
			'active_callback' => 'music_center_if_latest_albums_enabled',
			'type'			=> 'select',
			'choices'		=> music_center_get_post_choices(),
		)
	);

	$wp_customize->add_setting(
	'music_center_latest_albums_songs_no_'.$i,
	array(	
	'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'music_center_latest_albums_songs_no_'.$i,
	array(
	'label'       => __('No. of songs and release year', 'music-center').$i,  
	'section'     => 'music_center_latest_albums',   		
	'type'        => 'text',
	'active_callback'	=> 'music_center_if_latest_albums_enabled',
	)
);
}