<?php
/**
 * Template part for displaying front page introduction.
 *
 * @package Music Center
 */

// Get the content type.
$latest_albums = get_theme_mod( 'music_center_latest_albums', 'disable' );
// Bail if the section is disabled.
if ( 'disable' === $latest_albums ) {
	return;
}

$btn    = get_theme_mod( 'music_center_latest_albums_button_label', __( 'VIEW ALL RELEASE', 'music-center') );
$latest_albums_title    = get_theme_mod( 'music_center_latest_albums_title', __( 'Latest Release!!', 'music-center') );
$latest_albums_subtitle    = get_theme_mod( 'music_center_latest_albums_sub_title', __( 'NEWEST ALBUMS & SINGLES.', 'music-center') );
$latest_albums_description    = get_theme_mod( 'music_center_latest_albums_description', __( 'Proving that they are not your average country band, M-Slide blends old-fashioned country charm, lyrical wit and rock n’ roll grit into radio-friendly, hook-heavy pop nuggets.', 'music-center') );

$get_content = music_center_get_section_content( 'latest_albums', $latest_albums, 3  );

?>

<div id="latest-albums" class="pt col-2">
    <div class="container">
        <div class="latest-item clear">
            <article>
                <div class="section-header">
                    <?php if( !empty( $latest_albums_subtitle ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $latest_albums_subtitle ); ?></p>
                    <?php endif;

                    if( !empty( $latest_albums_title ) ):

                        ?>
                        <h2 class="section-title"><?php echo esc_html( $latest_albums_title ); ?></h2>
                    <?php endif; ?>

                </div>

                <?php if( !empty( $latest_albums_description ) ): ?>
                    <div class="section-content clear">
                        <p><?php echo esc_html( $latest_albums_description ); ?></p>
                    </div><!-- .section-content -->
                <?php endif; ?>

                <?php if( !empty( get_theme_mod('music_center_latest_albums_button_url') ) && !empty( $btn ) ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url( get_theme_mod('music_center_latest_albums_button_url') ); ?>" class="button"><?php echo esc_html( $btn ); ?></a>
                </div><!-- .read-more -->
            <?php endif; ?>
        </article><!-- article -->

        <article>

            <?php $i=1; foreach ( $get_content as $content ): ?>                            

            <div class="albums-wrapper">
                <div class="featured-image" style="background-image: url('<?php echo esc_url( get_the_post_thumbnail_url( $content['id'] ) ) ; ?>');">
                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>

                        <?php if( !empty( get_theme_mod( 'music_center_latest_albums_songs_no_'.$i ) ) ): ?>
                            <p><?php echo esc_html( get_theme_mod( 'music_center_latest_albums_songs_no_'.$i ) ); ?></p>

                        <?php endif; ?>

                    </header>
                </div><!-- .featured-image -->
            </div><!-- .album-wrapper -->

            <?php $i++; endforeach; ?>

        </article><!-- .article -->
    </div><!-- .latest-item -->
</div>

</div><!-- #latest -->